1 **Title**

2 Relationships between highly skilled golfers’ clubhead velocity and kinetic variables during a

3 countermovement jump

4 **Authors**

5 Jack ET Wells \[1\], Andrew CS Mitchell \[2\] ., Laura H Charalambous \[2\], and Iain M Fletcher \[2\]

6 1 The Professional Golfers’ Association, National Training Academy, Ping House, The

7 Belfry, United Kingdom

8 2 Institute for Sport and Physical Activity Research, University of Bedfordshire, United

9 Kingdom

10 **Corresponding author details**

11 Dr Jack Wells

12 The PGA National Training Academy

13 Ping House

14 The Belfry

15 Sutton Coldfield

16 B76 9PW

17 E-Mail: <jackwells009@gmail.com>

18 Telephone Number: +44 (0)1675 624792

19 Social media

20 Dr Jack Wells: @jackwells009

21 Dr Andrew Mitchell: @ACS_Mitchell

1

22 **Abstract**

23 Previous research has sought to establish the relationship countermovement jump (CMJ)

24 performance has with clubhead velocity (CHV). However, these investigations either assessed

25 lower skilled golfers, or utilised field-based protocols which are unable to assess a number of

26 biomechanical variables. Fifty highly skilled golfers performed CMJs on Kistler force

27 platforms in laboratory conditions. The CMJ variables included positive impulse, net impulse,

28 average power, peak power, peak force, force at zero velocity and jump height. Clubhead

29 velocity was measured using a TrackMan 3e launch monitor at a driving range. A Pearsons

30 correlation was employed to measure the strength and direction of the relationships between

31 CHV and CMJ derived performance variables. Results indicated strong positive relationships

32 (all _p’s_ \<0.001) between CHV and positive impulse ( _r_ = 0.695), net impulse ( _r_ = 0.689),

33 average power ( _r_ = 0.645), peak power ( _r_ = 0.656), peak force ( _r_ = 0.517) and force at zero

34 velocity ( _r_ = 0.528) with no significant relationship with jump height. However, if investigators

35 only have access to field-based protocols, it is recommended that they measure jump height

36 and utilise inverse dynamics to calculate take-off velocity. By multiplying take-off velocity by

37 mass, this allows the attainment of net impulse.

38 Key words: Golf, Physical Profiling, Impulse, Power, Peak Force, Vertical Jump

39 **Introduction**

40 Golfers who drive the ball over greater distances are significantly more likely to achieve lower

41 scores on par-4 and par-5 holes (Hellström et al., 2014). A revolutionary approach referred to

42 as ‘strokes gained’ highlighted that if a PGA Tour player could increase their drive distance

43 (DD) by 20-yards, this would save them 0.75 strokes per round (Broadie, 2014). Saving 0.75

44 strokes per round equates to three strokes over a four-day tournament, which could potentially

45 improve tour rankings and earnings. Whilst DD is representative of an externally valid measure

2

46 of golf performance, this is affected by a number of variables such as environmental conditions

47 (Cochran and Stobbs, 1999), centredness of strike (Betzler et al., 2014) and ball temperature

48 (Carlsson et al., 2019). Given the aforementioned issues with DD, researchers have sought to

49 employ clubhead velocity (CHV) as a dependent variable (Bliss et al., 2014; Fletcher and

50 Hartwell, 2004), as this is the single most important impact factor in determining ball velocity

51 and DD (Betzler et al., 2014; Sweeney et al., 2013).

52 During the golf swing, the interface between the ground and the golfer has been cited as an

53 important interaction for generating CHV (Lynn and Wu, 2018). Nesbit and Serrano (2005)

54 evidenced that the downswing is initiated from the ground-up, with energy transferred through

55 the kinetic chain in order to optimise CHV at impact. In addition, Nesbit and Serrano (2005)

56 also noted a commensurate decrease in both peak power and CHV with an increase in handicap.

57 Recent research has highlighted that at the point between the mid-backswing (club horizontal

58 to the ground) and late backswing (club vertical), highly skilled golfers apply ground reaction

59 forces to reverse their momentum back towards the target (Han et al., 2019). This is of great

60 importance given that greater force generated over a longer time would theoretically increase

61 impulse, which would therefore directly increase the change in momentum. Although ground

62 reaction forces work in different vectors during the swing, the greatest magnitude is in the

63 vertical direction, which can be extremely large for golfers with high CHV (Lynn and Wu,

64 2018). With regards to the combined vertical ground reaction forces (vGRFs), there is an

65 unweighting phase which begins in the mid-backswing (arms past parallel), reaching its vertex

66 (the lowest point in the force-time curve) at the top of the backswing (Han et al., 2019).

67 Following this, there is a rapid rise in vGRFs which peak between the early- to mid-downswing

68 (Han et al., 2019). Both vertex (unweighting and positive peak force) have been shown to

69 significantly relate to CHV (Han et al., 2019). Given the inherent importance of these vGRFs,

70 researchers and strength and conditioning (S&C) practitioners have employed

3

71 countermovement jumps (CMJ) to physically profile golfers (Hellström, 2008; Wells et al.,

72 2018).

73 The CMJ is a commonly utilised protocol to assess the physical capacity of athletes within a

74 wide variety of sports. Previous research has employed the CMJ to assess variables such as

75 peak power, average power, net impulse (Mundy et al., 2017), positive impulse (Wells et al.,

76 2019), peak force, force at zero velocity (Heishman et al., 2019) and jump height (McBride et

77 al., 2010). Within golf, a number of investigations have utilised the CMJ in their research

78 designs (Hellström, 2008; Read et al., 2013). However, there is no research that has sought to

79 assess the relationship between CHV and a number of CMJ derived performance variables

80 within highly skilled golfers. Previous research has observed no significant relationship, but a

81 moderate effect size ( _r_ = 0.30) between CMJ peak force and CHV in a sample of low skilled

82 golfers (handicap = 14.5 ± 7.3) (Leary et al., 2012). This is of concern, given that less skilled

83 golfers have been observed to present greater variability in CHV (Betzler et al., 2012), therefore

84 it is difficult to establish whether this relationship was due to skill (technique) or physical

85 capacity (force production). During a CMJ, zero velocity will be achieved at the lowest point

86 during the jump, whereby the muscle action will be working isometrically. When considering

87 the golf swing of highly skilled golfers, the downswing is initiated from the ground up and at

88 a slower rate (i.e. lower velocity) (Nesbit and Serrano (2005). As such, it would be noteworthy

89 to explore if CHV significantly related to force at zero velocity within a CMJ.

90 Field-based research has highlighted significant relationships between CHV and both CMJ

91 height ( _r_ = 0.47, _p_ \<0.01, Hellström, 2008), and peak power ( _r_ = 0.54, _p_ \<0.01, Read et al.,

92 2013). However, both of these investigations were conducted without force platforms which

93 limits the extractable data from the CMJ. When utilising force platforms, Sheehan, Watsford

94 and Pickering Rodriguez, (2019) reported that golfers with higher CHV had significantly

4

95 greater relative peak power (peak power / mass) than a low CHV group. However, this

96 investigation was comprised of a heterogenous sample of golfers (handicap = 9.89 ± 8.36

97 strokes). When considering these limitations, there is an inherent requirement for research to

98 assess the relationships between highly skilled golfers’ CHV and CMJ performance using force

99 platforms. Additionally, although research has reported statistically significant relationships

100 and large effect sizes ( _r_ ’s >0.50) between CHV and CMJ peak power (Read et al., 2013), there

101 is growing body of research questioning the use of power as a measure of physical performance

102 (Knudson, 2009; Linthorne, 2020; Winter et al., 2016).

103 The change in momentum ( _mass x velocity_ ) of a body is directly proportional to the application

104 of impulse ( _force x time_ ). Since mass remains constant during the golf swing, an increase in

105 impulse, if transferred effectively, will directly increase the velocity of the distal segments (i.e.

106 the clubhead). Recent research utilising force platforms has highlighted that CMJ positive

107 impulse significantly related to highly skilled golfers’ CHV ( _r_ = 0.788, _p_ \<0.001) (Wells et al.,

108 2018). This is also an important consideration when utilising jump height to assess golfers. For

109 instance, assuming the same net impulse is applied to the system, an increase in mass will

110 results in a reduced take-off velocity and therefore reduced jump height. Investigating the

111 relationships between CMJ derived performance variables and CHV would help to support

112 decision making for practitioners when profiling golfers. Consequently, the aim of this

113 investigation was to assess the relationships between highly skilled golfers’ CHV and CMJ net

114 impulse, positive impulse, peak power, average power, force at zero velocity, peak force and

115 jump height. It was hypothesised that highly skilled golfers’ CHV would hold significant

116 positive relationships with each of the variables measuring during the CMJ.

117

118

5

119 **Methods**

120 _**Study design**_

121 A cross-sectional correlation study using highly skilled golfers was conducted to assess the

122 relationships between CHV and kinetic variables within a CMJ. The countermovement jump

123 was employed since this has been utilised extensively within previous research (Read et al.,

124 2013; Wells et al., 2018). Golfers’ CHV was identified as the dependent variable with CMJ net

125 impulse, positive impulse, peak power, average power, force at zero velocity, peak force and

126 jump height employed as independent variables. Each participant was assessed by the same

127 experimenter to ensure standardised procedures. Clubhead velocity assessment and laboratory

128 analysis was conducted on separate days utilising a counterbalanced design.

129 _**Participants**_

130 Fifty right-handed male category-1 (handicap ≤5.4) golfers (age: 20 ± 1.8 years, height: 1.81 ±

131 0.05 m, mass: 75.5 ± 12.1 kg, handicap: 2.9 ± 1.9), with limited training history were recruited

132 to participate in this investigation using convenience sampling. A priori power analysis

133 (G\*Power, Version 3.1.9.2, University of Dusseldorf, Germany) determined that to achieve a

134 statistical power ≥0.8, a medium effects size (0.35) and alpha level of 0.05 a total of 49

135 participants were required. All participants were experienced golfers, engaged in an average of

136 10.5 ± 5.8 hours golf practice per week. Participants were injury free, attended a familiarisation

137 session and refrained from exercise 48 hours prior to all testing. Ethical approval was granted

138 by the University’s Ethics Committee. Participants were informed of the benefits and risks of

139 the investigation prior to providing written informed consent.

140

141

6

142 _**Procedures**_

143 Data were collected in the Sport and Exercise Science Laboratory at the XXXXXXXXXX XX

144 XXXXXXXXXXXX (XXXXXXXXXXXX, XX) _._ Anthropometric data for height (Holtain,

145 Model: Harpenden, Supplier: Holtain Ltd) and mass (Tanita, Model: BWB-800, Supplier:

146 Cranlea Ltd) were recorded following the completion of a PAR-Q and an informed consent

147 form. As a warm-up, participants performed a pulse raiser on a cycle ergometer (Monark

148 Ergomedic 874E, Cranlea Human Performance Ltd, UK) for five minutes at a cadence of 50

149 rpm with a resistance that yielded an intensity of 90-100 W. Following this a series of dynamic

150 stretches were performed including clock lunges, overhead squats, gluteal bridges, scapula wall

151 slides, thoracic rotation, hip rotations and vertical and horizontal arm swings. Each participant

152 received five minutes rest prior to completing the trials.

153 _**Countermovement Jumps**_

154 Participants received a standardised verbal explanation by the researcher who is an accredited

155 S&C coach with the UKSCA. Following this, participants performed three practice trials of the

156 CMJ prior to completing the test procedures. The CMJs were performed on dual Kistler force

157 platforms (Kistler 9281, Kistler Instruments, Winterthur, Switzerland) sampling at 2000 Hz.

158 Force platforms were zeroed with the participants standing motionless in their start position.

159 Countermovement jumps started with the participants standing upright before lowering

160 themselves into a self-selected squat depth and immediately jumping as high and as fast as

161 possible. Countermovement jumps were performed three times with the feet hip width apart,

162 hands placed on the hips, and with the initiation of the jump occurring on the command “3, 2,

163 1, jump” following a 1 second ‘quiet phase’ to establish a clear baseline measure. Each trial

164 was interspersed with a two-minute recovery period with the participants sitting on a chair.

165

7

166 _**Clubhead Velocity Assessment**_

167 Clubhead velocity was measured in a private swing studio at the XXXXXX XXXX XXXXXX

168 (XXXXXXXXXXXX, XX), hitting onto a range. This was conducted on a separate day to

169 laboratory assessment. Clubhead velocity was measured using a TrackMan 3e launch monitor

170 (Interactive Sports Games, Denmark) (Olivier et al., 2016). The TrackMan 3e launch monitor

171 measures the CHV from the geometric centre of the clubhead at the instantaneous moment

172 prior to impact (TrackMan, 2021). The TrackMan has been evidenced to have a median offset

173 of -0.48 m \[.\] s \[-1\] and be within 1.12 m \[.\] s \[-1 \] 87% of the time when compared to a benchmark system

174 (Leach et al., 2017). The TrackMan was set-up based on the manufacturer’s guidelines with

175 the investigator specifying the intended target line to the participants. The dynamic warm-up

176 followed the same procedures used as the laboratory testing. As part of a golf specific warm

177 up, participants also hit a self-selected number of shots (7 ± 2 shots) with a 6-iron whilst

178 gradually increasing their CHV. This was then followed with a self-selected number of shots

179 (7 ± 2 shots) struck with a driver. Participants used their own custom fitted 6-iron and driver.

180 Prior to data collection the investigator instructed each participant to ensure they struck the ball

181 with maximum effort, whilst maintaining their normal swing mechanics and a centred strike

182 on the clubface. The final two warm-up shots were instructed to be struck with maximum effort

183 to ensure participants were suitably prepared. Participants self-selected and struck 10 new

184 range balls with their driver, aiming at the target and hit off an artificial turf mat and a self

185 selected tee height. Centredness of strike was determined by sound, feel and the ball flight,

186 with the investigator checking verbally with the participant after each shot. Shots that were

187 deemed non-centred, sub-maximal or were hit with varying swing mechanics were discarded

188 from the data and the trial was subsequently re-performed up to a maximum of 15 shots.

189

8

190 _**Data analysis**_

191 The initiation of the unweighting phase in the CMJ was established using a 10 N shift from

192 baseline. Acceleration was calculated from Newtons Second Law of motion, which was then

193 integrated with respect to time to calculate vertical velocity of the centre of mass (COM) using

194 the trapezoid rule. The propulsive phase was established from the point where negative velocity

195 first changed to positive (the lowest position of the COM) up until the point of take-off. A 300

196 ms portion of the flight phase was used to calculate average force, with a 10 N threshold

197 employed to establish take-off. Force at zero velocity was calculated from the point where

198 velocity first changed from a negative to a positive value. Peak force was calculated from the

199 instantaneous time point where the force was greatest during the propulsive phase of the CMJ,

200 excluding the vGRFs generated through system weight. Both average power and peak power

201 were calculated from the vGRFs including system weight (Mundy et al., 2017). Average power

202 was calculated from the initiation of the propulsive phase up until take-off using the trapezoid

203 rule, whereas peak power was determined from the integral that generated the greatest value

204 within this phase. Positive impulse for the CMJ was calculated from the area underneath the

205 force-time curve where force first rose above zero, which is the time point when peak negative

206 (downward) velocity of the COM is reached (McMahon et al., 2018), up until the point that

207 force crossed back over zero and peak positive (upward) velocity of the COM is reached. Net

208 impulse was calculated from the area above the force-time curve (positive impulse) minus the

209 area below the force time curve from the initiation of unweighting until take-off. Both positive

210 impulse and net impulse were calculated from the net force which excludes the vGRFs

211 generated by the system weight (Mundy et al., 2017). Each participant’s take-off velocity of

212 the COM was calculated through dividing net impulse by their respective body mass as

213 recommended by Linthorne (2001). Jump height was then calculated using the following

214 equation:

9

215 Jump height = _v_ _\[2\]_ _to / 2 g_

216 Where _v_ = velocity at take-off and _g_ = gravity.

217 _**Statistical analysis**_

218 Intra-session reliability of test measures was assessed using an average-measures 2-way

219 random intraclass correlation coefficient (ICC) with absolute agreement and 95% confidence

220 intervals and the coefficient of variation (CV%). Interpretation of ICC values was in

221 accordance with previous research by Koo & Li, (2016), where values of \<0.5 = poor, 0.5-0.75

222 = moderate, 0.75-0.9 = good and >.0.9 = excellent. Reliability for the CV% was accepted as

223 those that achieved \<10% (Cormack et al., 2008). Both the ICC and CV% was calculated for

224 individual participants’ three trials to provide an overall reliability score across participants.

225 The CV% was calculated using the following equation:

226 CV% = (standard deviation / mean) * 100

227 The trial with the maximum values were taken forward for statistical analysis. The group means

228 and standard deviations were calculated for the countermovement jump and shots hit with the

229 driver. The assumptions of normal distribution and outliers were assessed through the visual

230 inspection of histograms and boxplots respectively, with linearity and homoscedasticity

231 assessed through the inspection of scatterplots. All statistical assumptions were met within

232 these data. Pearson correlation analysis was employed to measure the strength and direction of

233 relationships between CHV and variables analysed within the CMJ. IBM SPSS for Microsoft

234 Windows (version 26.0; Chicago, USA), with an alpha level of _p≤_ 0.05 used to assess statistical

235 significance. The effect size was determined as weak ( _r_ \< 0.3), moderate ( _r_ = 0.3-0.5) and

236 strong ( _r_ - 0.5) based on the thresholds established by Cohen (1988).

237

10

238 **Results**

239 Intra-session reliability for each of the variables was deemed excellent given that each ICC was

240 >0.9 (Table 1). Additionally, the CV% were all lower than the set threshold of 10% (Table 1).

241 Countermovement jump net impulse, positive impulse, peak power, average power, peak force,

242 and force at zero velocity all presented strong significant positive relationships with CHV

243 (Table 2). Both CMJ net impulse and positive impulse had the strongest relationships with

244 CHV, whereas jump height was not statistically significant.

245

246 Table 1: Intra-session ICC, CV% and their respective 95% confidence intervals (CI) for

247 clubhead velocity and the variables measured during the countermovement jump.

95% CI 95% CI

ICC Lower Upper CV% Lower Upper

Clubhead velocity .997 .995 .998 0.84 0.75 0.92

Net impulse .988 .980 .993 1.79 1.43 2.16

Positive impulse .987 .980 .992 1.93 1.60 2.27

Average power .982 .971 .989 2.87 2.42 3.32

Peak power .989 .983 .994 2.17 1.83 2.51

Peak force .967 .947 .980 3.60 2.93 4.27

Force at zero velocity .956 .929 .974 6.27 4.67 7.88

Jump height .982 .971 .989 3.57 2.87 4.28

248

249

250

251

252

253

11

254 Table 2: Mean and standard deviation for the countermovement jump and driver clubhead

255 velocity along with Pearsons correlation ( _r_ ) and the coefficient of determination ( _R_ _\[2\]_ ) for each

256 of the variables measured.

Mean SD _r_ _R_ _\[2\]_

Clubhead velocity (m \[.\] s \[-1\] ) 49.21 2.54     -

Net impulse (N \[.\] s) 180.92 26.00 0.689\* 0.475

Positive impulse (N \[.\] s) 282.70 42.98 0.695\* 0.483

Average power (W) 1771.94 295.08 0.645\* 0.416

Peak power (W) 3435.32 553.51 0.656\* 0.430

Peak force (N) 876.21 158.67 0.517\* 0.267

Force at zero velocity (N) 821.86 188.41 0.528\* 0.279

Jump height (m) 0.30 0.06 0.176 0.031

257 - _p_ \<0.001

258 **Discussion and Implications**

259 The aim of this investigation was to assess the relationships between highly skilled golfers’

260 CHV and CMJ net impulse, positive impulse, average power, peak power, peak force, force at

261 zero velocity and jump height. The findings of this investigation indicate that each of the

262 variables measured presented excellent intra-session reliability (all variables ICC >0.9 and CV

263 \<10%) (Table 1). There were strong significant relationships between CHV and CMJ positive

264 impulse, net impulse, average power, peak power, peak force and force at zero velocity which

265 agreed with our hypothesis. However, jump height did not significantly relate to CHV which

266 disagreed with our hypothesis.

267 This investigation was the first to assess the relationship between highly skilled golfers’ CHV

268 and force at zero velocity within a CMJ, which was found to be statistically significant ( _r_ =

269 0.528, _p_ \<0.001). Muscle actions that occur at zero velocity are isometric in nature, which, when

12

270 compared to a concentric action, allows the attainment of greater force due to the force-velocity

271 relationship. As golfers rotate into their backswing, the muscles in the lower body work

272 eccentrically to engage a stretch-shorten cycle. At around 100 ms prior to the club reaching the

273 top of the backswing, highly skilled golfers stop rotating their pelvis (Han et al., 2019),

274 therefore the muscles in the lower body work isometrically to reverse momentum back towards

275 the target. Further still, Nesbit and Serrano (2005) stated that highly skilled golfers work at a

276 slower rate during the start of the downswing, thus enabling them to attain greater force.

277 Generating more force earlier in the golf swing may result in a greater velocity of the more

278 distal segments if transferred effectively.

279 The importance of generating greater force is further supported given the strong significant

280 positive relationships between CMJ peak force and CHV ( _r_ = 0.517, _p_ \<0.001). Research has

281 previously observed no significant relationship, but a moderate effect size ( _r_ = 0.30) between

282 average CHV and CMJ peak force (Leary et al., 2012). However, the small ( _n_ = 12) and

283 heterogenous (handicap = 14.7 ± 8.7 stroke) sample could be confounding the observed

284 relationship. Given that the current investigation utilised a sample comprised of category-1

285 golfers, it is less likely that technical proficiency negatively affected CHV. Han et al., (2019)

286 reported that peak bilateral vGRFs during the golf swing significantly related to CHV in highly

287 skilled players. Applying greater vGRFs increases frontal plane torque within the downswing,

288 thus enabling greater CHV (Han et al., 2019). As such, this would support the findings within

289 the current investigation highlighting that CMJ peak force significantly related to CHV. It is

290 important to recognise that highly skilled golfers will adopt different swing mechanics to

291 optimise impact conditions between the club and ball. As such, there will also be inherent

292 differences in the utilisation of the three principal GRFs. For instance, a golfer may seek to

293 utilise greater anterior and posterior GRFs to increase horizontal plane torque. However, a

13

294 different golfer may adopt a strategy of increasing frontal plane torque through the application

295 of vertical or medial to lateral GRFs.

296 The calculation of jump height is commonplace within field-based research and the golf fitness

297 industry as a whole (Hellström, 2008; Read et al., 2013). Previous research has highlighted

298 significant positive relationships between CMJ height and CHV ( _r_ = 0.44, _p_ \<0.05, Read et al.,

299 2013; _r_ = 0.55, _p_ \<0.05, Sheehan et al., 2019), which is contrasting to the findings within the

300 current investigation. It is important to recognise that jump height is inherently determined and

301 confounded by the mass of the golfer. For instance, a golfer with a heavier mass will need to

302 produce greater vGRFs to attain the same jump height as a golfer with a smaller mass. This

303 issue is further substantiated given that there is also a significant positive relationship between

304 body mass and CHV ( _r_ = 0.51, _p_ \<0.01, Hellström, 2008). This creates issues for practitioners

305 when utilising jump height to track a golfer’s progress. For instance, if the golfer engages in a

306 hypertrophy loading programme to increase their mass, this may negatively affect jump height

307 in subsequent follow-up testing. As such, the mass of the golfer creates a third variable problem

308 when measuring the relationships between jump height and CHV.

309 There were significant relationships between highly skilled golfers CHV and CMJ peak power

310 ( _r_ = 0.656, _p_ \<0.001) which are similar to those reported in field-based research ( _r_ = 0.61,

311 _p_ \<0.01, Hellström, 2008; _r_ = 0.54, _p_ \<0.01, Read et al., 2013). The calculation of peak power

312 is achieved through multiplying the velocity of the centre of mass with the vGRFs inclusive of

313 body weight. Given the previous suggestion regarding the confounding nature of mass with

314 jump height, the inclusion of weight in calculating power is a plausible reason as to why there

315 is a strong significant relationship between peak power and CHV. Although a strong

316 relationship exists between these variables, it is important to recognise that peak power is an

317 instantaneous metric. The current investigation also observed a strong significant positive

14

318 relationship between average power and CHV ( _r_ = 0.645, _p_ \<0.001). These findings differ

319 somewhat to Leary et al., (2012) who noted a non-significant relationship ( _r_ = 0.36) between

320 lower skilled golfer CHV and CMJ average power. Although the current investigation observed

321 a strong relationship between CHV and power, it is erroneous to assume that power is a cause

322 and-effect variable. These concerns are highlighted when comparing individual golfers’

323 average power, jump height and relative power (average power / body mass) within this current

324 investigation. For instance, golfer 35 generated an average power of 1296.45 W and jumped

325 0.27 m, whereas golfer 42 had a greater average power 1520.22 W, but had a lower jump height

326 of 0.24 m. This is further substantiated given that golfer 42 had a greater relative power (23.21

327 W \[.\] kg \[-1\] ) than golfer 35 (19.64 W \[.\] kg \[-1\] ). This highlights that although a golfer may be more

328 ‘powerful’ during a CMJ, this does not necessarily translate into greater jump height.

329 Positive impulse ( _r_ = 0.695, _p_ \<0.001) and net impulse ( _r_ = 0.689, _p_ \<0.001) presented the

330 strongest relationships with CHV, albeit only marginally. (Table 2). Despite this, the _R_ _\[2\]_

331 difference between peak power and positive impulse is 5.3% (Table 2), which could make a

332 meaningful difference to a golfer. Therefore, positive impulse and net impulse are

333 recommended when seeking to physically profile golfers. The findings of this investigation are

334 supported by those of Wells et al., (2018) who highlighted a strong significant relationship ( _r_

335 = 0.788, _p_ \<0.001) between highly skilled golfers CHV and CMJ positive impulse. Given that

336 impulse is a re-expression of Newton’s Second Law of motion, this may explain why both net

337 impulse and positive impulse have stronger relationships with CHV when compared to both

338 average and peak power. As such, when working with golfers, it is recommended that

339 researchers seek to calculate impulse given that it directly relates kinetics to kinematics ( _r_ =

340 1.000) (Knudson, 2009). For instance, a golfer who increased their impulse would subsequently

341 increase their momentum. Since the mass of the golfers remains constant, any increase in

342 impulse, if transferred effectively, would directly increase the velocity, and therefore

15

343 momentum of the clubhead. Given the principle of conservation of linear momentum,

344 increasing the momentum of the clubhead would directly increase the momentum and therefore

345 the velocity of the golf ball, assuming centredness of strike remains constant.

346 For practitioners who employ the CMJ as a performance measure with golfers, it is

347 recommended that force platforms are utilised. Force platforms allow practitioners and

348 researchers to measure variables over a longer duration of the countermovement jump such as

349 impulse. However, it is important to recognise that force platforms are not always a viable

350 option for practitioners given that these can be prohibitively expensive. For practitioners who

351 have a more limited budget in performance testing, the CMJ can be measured using readily

352 available applications which have been validated against force plates (Balsalobre-Fernández et

353 al., 2015). Although jump height presented a non-significant relationship with CHV, there are

354 two notable advantages to calculating this using field-based protocols. Firstly, if body mass

355 remains constant, an increase in jump height would indicate that net impulse has increased.

356 Secondly, jump height can be used to calculate take-off velocity, which can then be multiplied

357 by a golfer’s mass to establish their net impulse. For instance, if a golfer jumps 0.35 m with a

358 mass of 77 kg, inverse dynamics can be used to calculate take-off velocity using the following

359 equation:

360 Take-off velocity = √( _d_ _(2_ _g_ ))

361 Take-off velocity = √(0.35\*(2\*9.81))

362 Take-off velocity = 2.62 m \[.\] s \[-1\]

363 Where _d_ = jump height and _g_ = gravity

364 The take-off velocity of the COM can then be incorporated in the following equation to

365 calculate net impulse:

16

366 Net impulse = _m_ - _v_

367 Net impulse = 77 kg * 2.62 m \[.\] s \[-1\]

368 Net impulse = 201.74 N \[.\] s

369 Where _m_ = mass and _v_ = take-off velocity of the centre of mass.

370 This is of great importance to practitioners who are only able to measure jump height using a

371 contact mat, smart phone or tablet. From obtaining jump height, this can then be used to

372 calculate the golfers net impulse, which was found to significantly relate to CHV within the

373 current investigation. It is important to recognise, however, that contact mats and phone

374 applications employ the flight time method, which can overestimate jump height by 0.5-2.0 cm

375 (Kibele, 1998). However, if the same procedures are used to profile and track golfers, this

376 metric will reliably overestimate jump height and therefore net impulse. Future research may

377 wish to assess the relationship between CHV and a number of kinetic variables measured

378 during other physical assessments such as a squat jump. This would further support the S&C

379 practitioner when working with golfers. It is important to note some inherent limitations within

380 this research. Firstly, there was no standardisation in the times in which testing took place.

381 Additionally, the instruction to hit the ball with maximum effort may not be representative of

382 a tournament setting. However, this was implemented to ensure that the intensity of each shot

383 was controlled.

384

385 **Conclusion**

386 The findings of this investigation highlight that the CMJ can be employed to reliably measure

387 net impulse, positive impulse, peak power, average power, force at zero velocity, peak force

388 and jump height. Apart from jump height, each of the aforementioned variables presented

17

389 strong significant relationships with highly skilled golfers CHV. Positive impulse and net

390 impulse presented the strongest relationships with CHV, therefore, these variables should be

391 utilised by both practitioners and researchers when working with golfers. For practitioners and

392 researchers who are only able to capture CMJ performance using a smart phone or contact mat,

393 it is recommended that jump height is measured. This is based on a number of important

394 considerations. Firstly, jump height can be used to calculate take-off velocity, which can then

395 be multiplied by a golfer’s mass to establish their net impulse for a given countermovement

396 jump. Calculating net impulse would be the most preferential metric given that peak power is

397 an instantaneous variable which is not representative of the whole CMJ. Additionally, a more

398 ‘powerful’ golfer may not necessarily present a greater jump height. These findings provide

399 guidelines for practitioners and researchers when working with golfers.

400 -Word count = 4485

401 **Acknowledgements**

402 The authors would like to thank the participants for their voluntary participation in this

403 investigation.

404 **Disclosure statement**

405 The authors report no conflict of interest.

406 **References**

407 1) Balsalobre-Fernández, C., Glaister, M. and Lockey, R. A. (2015) ‘The validity and

408 reliability of an iPhone app for measuring vertical jump performance’, _Journal of Sports_

409 _Sciences_, 33(15), pp. 1574–1579. [https://doi.org/10.1080/02640414.2014.996184](https://doi.org/10.1080/02640414.2014.996184)

410 2) Betzler, N.F., Monk, S.A., Wallace, E.S. and Otto, S.R. (2012) ‘Variability in clubhead

411 presentation characteristics and ball impact location for golfers’ drives’, _Journal of_

18

412 _Sports Sciences_, 30(5), pp. 439–448. <https://doi.org/10.1080/02640414.2011.653981>

413 3) Betzler, N.F., Monk, S.A., Wallace, E.S. and Otto, S.R. (2014) ‘The relationships

414 between driver clubhead presentation characteristics, ball launch conditions and golf shot

415 outcomes’, _Proceedings of the Institution of Mechanical Engineers, Part P: Journal of_

416 _Sports Engineering and Technology_, 228(4), pp. 242–249.

417 4) Bliss, A., McCulloch, H. and Maxwell, N.S. (2015) ‘The Effects of an Eight-Week

418 Plyometric Training Program on Golf Swing Performance Characteristics in Skilled

419 Adolescent Golfers’, _International Journal of Golf Science_, 4(2), pp. 120–135.

420 5) Broadie, M. (2014) _'Every Shot Counts'_ . USA: Penguin Group.

421 6) Carlsson, M., Nilsson, J., Hellström, J., Tinmark, F. and Carlsson, T. (2019) ‘The effect

422 of ball temperature on ball speed and carry distance in golf drives’, _Proceedings of the_

423 _Institution of Mechanical Engineers, Part P: Journal of Sports Engineering and_

424 _Technology_, 233(2), pp. 186–192.

425 7) Cochran, A. and Stobbs, J. (1999) ' _Search for the Perfect Swing'_, 6 \[th\] ed, Chicago, IL,

426 Triumph Books.

427 8) Cohen, J. (1988) ' _Statistical Power Analysis for the Behavioral Sciences'_ (2 \[nd\] ed.), New

428 Jersey, Lawrence Erlbaum.

429 9) Cormack, S.J., Newton, R.U., McGuigan, M.R. and Doyle, T.L. (2008). ‘Reliability of

430 measures obtained during single and repeated countermovement jumps’, _International_

431 _Journal_ _of_ _Sports_ _Physiology_ _and_ _Performance_, _3_ (2), pp.131-144.

432 [https://doi.org/10.1123/ijspp.3.2.131](https://doi.org/10.1123/ijspp.3.2.131)

433 10) Fletcher, I.M. and Hartwell, M. (2004) ‘Effect of an 8-week combined weights and

434 plyometrics training programme on golf drive performance’, _Journal of Strength and_

435 _Conditioning_ _Research,_ 18(1), pp. 59–62. [https://doi.org/10.1519/1533-](<https://doi.org/10.1519/1533-4287(2004)018%3C0059:eoawcw%3E2.0.co;2>)

436 4287(2004)018\<0059:eoawcw>2.0.co;2

19

437 11) Han, K.H., Como, C., Kim, J., Lee, S., Kim, J., Kim, D.K. and Kwon, Y.H. (2019)

438 ‘Effects of the golfer–ground interaction on clubhead speed in skilled male golfers’,

439 _Sports_ _Biomechanics_, 18(2), pp. 115–134.

440 [https://doi.org/10.1080/14763141.2019.1586983](https://doi.org/10.1080/14763141.2019.1586983)

441 12) Heishman, A., Daub, B., Miller, R., Brown, B., Freitas, E. and Bemben, M. (2019)

442 ‘Countermovement jump inter-limb asymmetries in collegiate basketball

443 players’, _Sports_, _7_ [(5), pp.1-15. https://doi.org/10.3390/sports7050103](https://doi.org/10.3390/sports7050103)

444 13) Hellström, J. (2008) ‘The Relation between Physical Tests, Measures, and Clubhead

445 Speed in Elite Golfers’, _International Journal of Sports Science and Coaching_, 3, pp. 85–

446 92.

447 14) Hellström, J., Nilsson, J. and Isberg, L. (2014) ‘Drive for dough. PGA Tour golfers’ tee

448 shot functional accuracy, distance and hole score’, _Journal of Sports Sciences_, 32(5), pp.

449 [462–469. https://doi.org/10.1080/02640414.2013.832353](https://doi.org/10.1080/02640414.2013.832353)

450 15) Kibele, A. (1998) ‘Possibilities and limitations in the biomechanical analysis of

451 countermovement jumps: A methodological study’, _Journal of Applied Biomechanics_,

452 14(1) 105–117.

453 16) Koo, T.K. and Li, M.Y. (2016) ‘A guideline of selecting and reporting intraclass

454 correlation coefficients for reliability research’, _Journal of Chiropractic Medicine_, _15_ (2),

455 [pp.155-163. https://doi.org/10.1016/j.jcm.2016.02.012](https://doi.org/10.1016/j.jcm.2016.02.012)

456 17) Knudson, D.V. (2009) ‘Correcting the use of the term “power” in the strength and

457 conditioning literature’, _Journal of Strength and Conditioning Research_, 23(6), pp.

458 1902–1908. [https://doi.org/10.1519/JSC.0b013e3181b7f5e5](https://doi.org/10.1519/jsc.0b013e3181b7f5e5)

459 18) Leach, R.J., Forrester, S.E., Mears, A.C. and Roberts, J.R. (2017) ‘How valid and

460 accurate are measurements of golf impact parameters obtained using commercially

461 available radar and stereoscopic optical launch monitors?’, _Measurement_, 112, pp. 125–

20

462 136. <https://doi.org/10.1016/j.measurement.2017.08.009>

463 19) Leary, B.K., Statler, J., Hopkins, B., Fitzwater, R., Kesling, T., Lyon, J., Phillips, B.,

464 Bryner, R.W., Cormie, P. and Haff, G.G. (2012) ‘The relationship between isometric

465 force-time curve characteristics and club head speed in recreational golfers’, _The Journal_

466 _of_ _Strength_ _&_ _Conditioning_ _Research_, 26(10), pp.2685-2697.

467 [https://doi.org/10.1519/JSC.0b013e31826791bf](https://doi.org/10.1519/jsc.0b013e31826791bf)

468 20) Linthorne, N.P. (2001) ‘Analysis of standing vertical jumps using a force platform’,

469 _American Journal of Physics_, 69(11), pp. 1198–1204. [https://doi.org/10.1119/1.1397460](https://doi.org/10.1119/1.1397460)

470 21) Linthorne, N.P. (2020) ‘The correlation between jump height and mechanical power in a

471 countermovement jump is artifically inflated’, Sports Biomechanics, pp. 1-19.

472 [https://doi.org/10.1080/14763141.2020.1721737](https://doi.org/10.1080/14763141.2020.1721737)

473 22) Lynn, S.K., Noffal, G.J., Wu, W. and Vandervoort, A.A. (2012) ‘Using Principal

474 Components Analysis to Determine Differences in 3D Loading Patterns Between

475 Beginner and Collegiate Level Golfers’, _International Journal of Golf Science_, 1(1), pp.

476 25–41.

477 23) Lynn, S.K. and Wu, W. (2018). 'The use of ground reaction forces and pressures in golf

478 swing instruction', In Toms, M. (Ed.), _Routledge International Handbook of Golf_

479 _Science_, 1 \[st\] ed., Oxford, Routledge, pp. 15-25.

480 24) McBride, J.M., Kirby, T.J., Haines, T.L. and Skinner, J. (2010) ‘Relationship between

481 relative net vertical impulse and jump height in jump squats performed to various squat

482 depths and with various loads’, _International Journal of Sports Physiology and_

483 _Performance_ [, 5(4), pp.484-496. https://doi.org/10.1123/ijspp.5.4.484](https://doi.org/10.1123/ijspp.5.4.484)

484 25) McMahon, J.J., Suchomel, T.J., Lake, J.P. and Comfort, P. (2018) ‘Understanding the

485 key phases of the countermovement jump force-time curve’, _Strength and Conditioning_

486 _Journal_ [, 40(4), pp. 96–106. https://doi.org/10.1519/SSC.0000000000000375](https://journals.lww.com/nsca-scj/Fulltext/2018/08000/Understanding_the_Key_Phases_of_the.10.aspx)

21

487 26) Mundy, P.D., Smith, N.A., Lauder, M.A. and Lake, J.P. (2017) ‘The effects of barbell

488 load on countermovement vertical jump power and net impulse’, _Journal of Sports_

489 _Sciences_ [, 35(18), pp. 1781–1787. https://doi.org/10.1080/02640414.2016.1236208](https://doi.org/10.1080/02640414.2016.1236208)

490 27) Nesbit, S.M. and Serrano, M. (2005) ‘Work and power analysis of the golf swing’,

491 _Journal of Sports Science and Medicine_, 4(4), pp. 520–533.

492 28) Olivier, M.H., Horan, S.A., Evans, K.A. and Keogh, J.W. (2016) ‘The effect of a seven

493 week exercise program on golf swing performance and musculoskeletal measures’,

494 _International Journal of Sports Science and Coaching_, 11(4), pp. 610–618.

495 [https://doi.org/10.1177/1747954116654784](https://doi.org/10.1177%2F1747954116654784)

496 29) Read, P.J., Lloyd, R.S., De Ste Croix, M. and Oliver, J.L. (2013) ‘Relationships between

497 field-based measures of strength and power and golf club head speed’, _Journal of_

498 _Strength_ _and_ _Conditioning_ _Research_, 27(10), pp. 2708–2713.

499 [https://doi.org/10.1519/JSC.0b013e318280ca00](https://doi.org/10.1519/jsc.0b013e318280ca00)

500 30) Sheehan, W.B., Watsford, M.L. and Pickering Rodriguez, E.C. (2019) ‘Examination of

501 the neuromechanical factors contributing to golf swing performance’, _Journal of Sports_

502 _Sciences_ [, 37(4), pp. 458–466. https://doi.org/10.1080/02640414.2018.1505185](https://doi.org/10.1080/02640414.2018.1505185)

503 31) Sweeney, M., Mills, P., Alderson, J. and Elliott, B. (2013) ‘The influence of club-head

504 kinematics on early ball flight characteristics in the golf drive’, _Sports Biomechanics_,

505 [12(3), pp. 247–258. https://doi.org/10.1080/14763141.2013.772225](https://doi.org/10.1080/14763141.2013.772225)

506 32) TrackMan (2021). Available from: [https://trackmangolf.com/what-we-track](https://trackmangolf.com/what-we-track) (Date

507 Accessed 10 \[th\] May 2021)

508 33) Wells, J.E.T., Mitchell, A.C.S, Charalambous, L.H. and Fletcher, I.M. (2018)

509 ‘Relationships between highly skilled golfers’ clubhead velocity and force producing

510 capabilities during vertical jumps and an isometric mid-thigh pull’, _Journal of Sports_

511 _Sciences_ [, 36(16), pp. 1847–1851. https://doi.org/10.1080/02640414.2018.1423611](https://doi.org/10.1080/02640414.2018.1423611)

22

512 34) Wells, J.E.T., Charalambous, L.H., Mitchell, A.C.S., Coughlan, D., Brearley, S.L.,

513 Hawkes, R.A., Murray, A.D., Hillman, R.G. and Fletcher, I.M. (2019) ‘Relationships

514 between Challenge Tour golfers’ clubhead velocity and force producing capabilities

515 during a countermovement jump and isometric mid-thigh pull’, _Journal of Sports_

516 _Sciences_ [, 37(12), pp. 1381–1386. https://doi.org/10.1080/02640414.2018.1559972](https://doi.org/10.1080/02640414.2018.1559972)

517 35) Winter, E.M., Abt, G., Brookes, F.C., Challis, J.H., Fowler, N.E., Knudson, D.V.,

518 Knuttgen, H.G., Kraemer, W.J., Lane, A.M., Van Mechelen, W. and Morton, R.H. (2016)

519 ‘Misuse of “power” and other mechanical terms in sport and exercise science research’,

520 _The_ _Journal_ _of_ _Strength_ _&_ _Conditioning_ _Research_, 30(1), pp.292-300.

521 <https://doi.org/10.1519/JSC.0000000000001101>

23
